@@ -14,11 +14,11 @@ It defined relationships methods to extract columns data only of relationships
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 
 =head1 SYNOPSIS
@@ -72,7 +72,14 @@ sub get_column_data
     my ($obj, $options) = @_;
     my $rh_data;
     my $class = ref $obj;
-    my @columns = $class->columns;
+    my @columns;
+    if (defined $options->{columns} && ref $options->{columns} eq 'ARRAY' ){
+        @columns = @{$options->{columns}};
+    }
+    else {
+        @columns = $class->columns;
+    }
+
     foreach my $key (@columns)
     {
         unless ($options->{with_all_fields})
